# Generated by Django 3.2.12 on 2022-03-28 16:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('simpel_payments', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='payment',
            name='status',
            field=models.IntegerField(choices=[(1, 'Pending'), (0, 'Validated'), (2, 'Rejected'), (3, 'Approved'), (4, 'Canceled')], default=1, verbose_name='Status'),
        ),
    ]
